from django.contrib import admin
from django.db import models

from .widgets import AdminMarkdownxWidget
from .models import MarkdownxField


class MarkdownxModelAdmin(admin.ModelAdmin):

    formfield_overrides = {
        MarkdownxField: {'widget': AdminMarkdownxWidget}
    }



from django.conf import settings
from django.utils.translation import ugettext_lazy as _

# Markdown extensions
MARKDOWNX_MARKDOWN_EXTENSIONS = getattr(settings, 'MARKDOWNX_MARKDOWN_EXTENSIONS', [])
MARKDOWNX_MARKDOWN_EXTENSION_CONFIGS = getattr(settings, 'MARKDOWNX_MARKDOWN_EXTENSION_CONFIGS', {})

# Markdown url
MARKDOWNX_URLS_PATH = getattr(settings, 'MARKDOWNX_URLS_PATH', '/markdownx/markdownify/')
MARKDOWNX_UPLOAD_URLS_PATH = getattr(settings, 'MARKDOWNX_UPLOAD_URLS_PATH', '/markdownx/upload/')

# Media path
MARKDOWNX_MEDIA_PATH = getattr(settings, 'MARKDOWNX_MEDIA_PATH', 'markdownx/')

# Image
MARKDOWNX_UPLOAD_MAX_SIZE = getattr(settings, 'MARKDOWNX_UPLOAD_MAX_SIZE', 52428800) # 50MB
MARKDOWNX_UPLOAD_CONTENT_TYPES = getattr(settings, 'MARKDOWNX_UPLOAD_CONTENT_TYPES', ['image/jpeg', 'image/png'])
MARKDOWNX_IMAGE_MAX_SIZE = getattr(settings, 'MARKDOWNX_IMAGE_MAX_SIZE', {'size': (500, 500), 'quality': 90,})

# Editor
MARKDOWNX_EDITOR_RESIZABLE = getattr(settings, 'MARKDOWNX_EDITOR_RESIZABLE', True)

# Translations
LANGUAGES = getattr(settings, 'LANGUAGES', (
    ('en', _('English')),
    ('pl', _('Polish')),
)
)



from django import forms
from django.template import Context
from django.template.loader import get_template
from django.contrib.admin import widgets

from .settings import (
    MARKDOWNX_EDITOR_RESIZABLE,
    MARKDOWNX_URLS_PATH,
    MARKDOWNX_UPLOAD_URLS_PATH,
)


class MarkdownxWidget(forms.Textarea):

    def render(self, name, value, attrs=None):
        if attrs is None:
            attrs = {}
        elif 'class' in attrs:
            attrs['class'] += ' markdownx-editor'
        else:
            attrs.update({'class':'markdownx-editor'})

        attrs['data-markdownx-editor-resizable'] = MARKDOWNX_EDITOR_RESIZABLE
        attrs['data-markdownx-urls-path'] = MARKDOWNX_URLS_PATH
        attrs['data-markdownx-upload-urls-path'] = MARKDOWNX_UPLOAD_URLS_PATH

        widget = super(MarkdownxWidget, self).render(name, value, attrs)

        t = get_template('markdownx/widget.html')
        c = Context({
            'markdownx_editor': widget,
        })

        return t.render(c)

    class Media:
        js = (
            'markdownx/js/markdownx.js',
        )


class AdminMarkdownxWidget(MarkdownxWidget, widgets.AdminTextareaWidget):

    class Media:
        css = {
            'all': ('markdownx/admin/css/markdownx.css',)
        }
        js = (
            'markdownx/js/markdownx.js',
        )



from setuptools import setup, find_packages

import os
if 'vagrant' in str(os.environ):
    del os.link


def get_requirements():
    return open('requirements.txt').read().splitlines()


setup(
    name='django-markdownx',
    version='1.4',
    packages=find_packages(),
    include_package_data=True,
    description='Django Markdown editor with image uploads (stored in MEDIA_ROOT folder) and live preview.',
    url='https://github.com/adi-/django-markdownx',
    author='adi-',
    author_email='aaadeji@gmail.com',
    license='BSD',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Topic :: Software Development',
        'Topic :: Software Development :: User Interfaces',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: JavaScript',
    ],
    keywords='django markdown live preview images upload',
    tests_require=get_requirements(),
    test_suite='runtests',
    install_requires=get_requirements(),
)
